# eric7.WebBrowser.UrlBar.BookmarkActionSelectionDialog

Module implementing a dialog to select the action to be performed on the bookmark.

### Global Attributes

None

### Classes

BookmarkAction | Class defining the available bookmark actions.
BookmarkActionSelectionDialog | Class implementing a dialog to select the action to be performed on the bookmark.

### Functions

None

## BookmarkAction

Class defining the available bookmark actions.

### Derived from

enum.Enum

### Class Attributes

AddBookmark
AddSpeeddial
EditBookmark
RemoveSpeeddial
Undefined

### Class Methods

None

### Methods

None

### Static Methods

None

Up

## BookmarkActionSelectionDialog

Class implementing a dialog to select the action to be performed on the bookmark.

### Derived from

QDialog, Ui_BookmarkActionSelectionDialog

### Class Attributes

None

### Class Methods

None

### Methods

BookmarkActionSelectionDialog | Constructor
getAction | Public method to get the selected action.
on_bookmarkPushButton_clicked | Private slot handling selection of a bookmark action.
on_speeddialPushButton_clicked | Private slot handling selection of a speed dial action.

### Static Methods

None

#### BookmarkActionSelectionDialog (Constructor)

BookmarkActionSelectionDialog(url, parent=None)

Constructor

url (QUrl)
  URL to be worked on
parent (QWidget)
  reference to the parent widget

#### BookmarkActionSelectionDialog.getAction

getAction()

Public method to get the selected action.

Return:
  reference to the associated action

Return Type:
  QAction

#### BookmarkActionSelectionDialog.on_bookmarkPushButton_clicked

on_bookmarkPushButton_clicked()

Private slot handling selection of a bookmark action.

#### BookmarkActionSelectionDialog.on_speeddialPushButton_clicked

on_speeddialPushButton_clicked()

Private slot handling selection of a speed dial action.

Up